@@ -33,7 +33,9 @@ class SdistArchive(object):
         self.gettarinfo = lambda *args, **kwargs: self.normalize_tar_metadata(self.tf.gettarinfo(*args, **kwargs))
 
     def create_file(self, contents, *relative_paths):
-        contents = contents.encode('utf-8')
+        # TODO: remove condition when we drop Python 2
+        if not isinstance(contents, bytes):
+            contents = contents.encode('utf-8')
         tar_info = tarfile.TarInfo(normalize_archive_path(os.path.join(self.name, *relative_paths)))
         tar_info.mtime = self.timestamp if self.reproducible else int(get_current_timestamp())
         tar_info.size = len(contents)
@@ -226,6 +228,7 @@ class SdistBuilder(BuilderInterface):
         return contents
 
     def get_default_build_data(self):
+        # Check for inclusion first to avoid redundant pattern matching
         build_data = {'artifacts': []}
         if not self.config.include_path('pyproject.toml'):
             build_data['artifacts'].append('/pyproject.toml')
@@ -240,7 +243,12 @@ class SdistBuilder(BuilderInterface):
                 if not self.config.include_path(license_file):
                     build_data['artifacts'].append('/{}'.format(license_file))
 
-        build_data['artifacts'].append('/{}'.format(DEFAULT_BUILD_SCRIPT))
+        if not self.config.include_path(DEFAULT_BUILD_SCRIPT):
+            build_data['artifacts'].append('/{}'.format(DEFAULT_BUILD_SCRIPT))
+
+        if not self.config.include_path('.gitignore'):
+            build_data['artifacts'].append('/.gitignore')
+
         return build_data
 
     @property
